==> calligra_2.8.1-1.orig.tar.xz: calligra-2.8.1/libs/kopageapp/tools/backgroundTool/KoPABackgroundTool.h <==
/* This file is part of the KDE project
 * Copyright (C) 2008 Carlos Licea <carlos.licea@kdemail.net>
 * Copyright (C) 2008 Thorsten Zachmann <zachmann@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef KOPABACKGROUNDTOOL_H
#define KOPABACKGROUNDTOOL_H

#include "kopageapp_export.h"

#include <KoToolBase.h>

class KoPAViewBase;

class KOPAGEAPP_EXPORT KoPABackgroundTool : public KoToolBase
{
    Q_OBJECT
public:
    explicit KoPABackgroundTool(KoCanvasBase *base);
    virtual ~KoPABackgroundTool();

    ///Reimplemented from KoToolBase
    virtual void paint( QPainter &painter, const KoViewConverter &converter );
    ///Reimplemented from KoToolBase
    virtual void activate(ToolActivation toolActivation, const QSet<KoShape*> &shapes);
    ///Reimplemented from KoToolBase
    virtual void deactivate();
    ///Reimplemented from KoToolBase
    virtual void mousePressEvent( KoPointerEvent *event );
    ///Reimplemented from KoToolBase
    virtual void mouseMoveEvent( KoPointerEvent *event );
    ///Reimplemented from KoToolBase
    virtual void mouseReleaseEvent( KoPointerEvent *event );

    KoPAViewBase * view() const;

    void addOptionWidget(QWidget *widget);
public slots:
    void slotActivePageChanged();

protected:
    ///Reimplemented from KoToolBase
    virtual QList<QWidget *> createOptionWidgets();

private:
    KoPAViewBase * m_view;
    QList<QWidget *> m_addOnWidgets;
};

#endif //KOPABACKGROUNDTOOL_H

==> calligra-2.9.0.tar.xz: calligra-2.9.0/libs/kopageapp/tools/backgroundTool/KoPABackgroundTool.h <==
/* This file is part of the KDE project
 * Copyright (C) 2008 Carlos Licea <carlos.licea@kdemail.net>
 * Copyright (C) 2008 Thorsten Zachmann <zachmann@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef KOPABACKGROUNDTOOL_H
#define KOPABACKGROUNDTOOL_H

#include "kopageapp_export.h"

#include <KoToolBase.h>

class KoPAViewBase;

class KOPAGEAPP_EXPORT KoPABackgroundTool : public KoToolBase
{
    Q_OBJECT
public:
    explicit KoPABackgroundTool(KoCanvasBase *base);
    virtual ~KoPABackgroundTool();

    ///Reimplemented from KoToolBase
    virtual void paint( QPainter &painter, const KoViewConverter &converter );
    ///Reimplemented from KoToolBase
    virtual void activate(ToolActivation toolActivation, const QSet<KoShape*> &shapes);
    ///Reimplemented from KoToolBase
    virtual void deactivate();
    ///Reimplemented from KoToolBase
    virtual void mousePressEvent( KoPointerEvent *event );
    ///Reimplemented from KoToolBase
    virtual void mouseMoveEvent( KoPointerEvent *event );
    ///Reimplemented from KoToolBase
    virtual void mouseReleaseEvent( KoPointerEvent *event );

    KoPAViewBase * view() const;

    void addOptionWidget(QWidget *widget);
public slots:
    void slotActivePageChanged();

protected:
    ///Reimplemented from KoToolBase
    virtual QList<QPointer<QWidget> > createOptionWidgets();

private:
    KoPAViewBase * m_view;
    QList<QPointer<QWidget> > m_addOnWidgets;
};

#endif //KOPABACKGROUNDTOOL_H
